@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2020, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -23,6 +24,7 @@
 
 #include "casmine.h"
 
+#include "wb_version.h"
 #include "wb_test_helpers.h"
 
 #include "mysql/MySQLLexer.h"
@@ -117,12 +119,12 @@ public:
 
   virtual Any visitSelectItem(MySQLParser::SelectItemContext *context) override {
     Any result = visitChildren(context);
-    results.push_back(result.as<EvalValue>());
+    results.push_back(std::any_cast<EvalValue>(result));
     return result;
   }
 
   virtual Any visitExprNot(MySQLParser::ExprNotContext *context) override {
-    EvalValue value = visit(context->expr());
+    EvalValue value = std::any_cast<EvalValue>(visit(context->expr()));
     switch (value.type) {
       case EvalValue::Null:
         return EvalValue::fromNotNull();
@@ -134,8 +136,8 @@ public:
   }
 
   virtual Any visitExprAnd(MySQLParser::ExprAndContext *context) override {
-    EvalValue left = visit(context->expr(0));
-    EvalValue right = visit(context->expr(1));
+    EvalValue left = std::any_cast<EvalValue>(visit(context->expr(0)));
+    EvalValue right = std::any_cast<EvalValue>(visit(context->expr(1)));
 
     if (left.isNullType() || right.isNullType())
       return EvalValue::fromNull();
@@ -145,8 +147,8 @@ public:
   }
 
   virtual Any visitExprXor(MySQLParser::ExprXorContext *context) override {
-    EvalValue left = visit(context->expr(0));
-    EvalValue right = visit(context->expr(1));
+    EvalValue left = std::any_cast<EvalValue>(visit(context->expr(0)));
+    EvalValue right = std::any_cast<EvalValue>(visit(context->expr(1)));
 
     if (left.isNullType() || right.isNullType())
       return EvalValue::fromNull();
@@ -154,8 +156,8 @@ public:
   }
 
   virtual Any visitExprOr(MySQLParser::ExprOrContext *context) override {
-    EvalValue left = visit(context->expr(0));
-    EvalValue right = visit(context->expr(1));
+    EvalValue left = std::any_cast<EvalValue>(visit(context->expr(0)));
+    EvalValue right = std::any_cast<EvalValue>(visit(context->expr(1)));
 
     if (left.isNullType() || right.isNullType())
       return EvalValue::fromNull();
@@ -163,7 +165,7 @@ public:
   }
 
   virtual Any visitExprIs(MySQLParser::ExprIsContext *context) override {
-    EvalValue value = visit(context->boolPri());
+    EvalValue value = std::any_cast<EvalValue>(visit(context->boolPri()));
     if (context->IS_SYMBOL() == nullptr)
       return value;
 
@@ -185,15 +187,15 @@ public:
   }
 
   virtual Any visitPrimaryExprIsNull(MySQLParser::PrimaryExprIsNullContext *context) override {
-    EvalValue value = visit(context->boolPri());
+    EvalValue value = std::any_cast<EvalValue>(visit(context->boolPri()));
     if (context->notRule() == nullptr)
       return EvalValue::fromBool(value.type == EvalValue::Null);
     return EvalValue::fromBool(value.type != EvalValue::Null);
   }
 
   virtual Any visitPrimaryExprCompare(MySQLParser::PrimaryExprCompareContext *context) override {
-    EvalValue left = visit(context->boolPri());
-    EvalValue right = visit(context->predicate());
+    EvalValue left = std::any_cast<EvalValue>(visit(context->boolPri()));
+    EvalValue right = std::any_cast<EvalValue>(visit(context->predicate()));
 
     ssize_t op = context->compOp()->getStart()->getType();
     if (left.isNullType() || right.isNullType()) {
@@ -236,8 +238,8 @@ public:
     if (context->simpleExpr() != nullptr)
       return visit(context->simpleExpr());
 
-    EvalValue left = visit(context->bitExpr(0));
-    EvalValue right = visit(context->bitExpr(1));
+    EvalValue left = std::any_cast<EvalValue>(visit(context->bitExpr(0)));
+    EvalValue right = std::any_cast<EvalValue>(visit(context->bitExpr(1)));
 
     if (left.isNullType() || right.isNullType())
       return EvalValue::fromNull();
@@ -305,7 +307,7 @@ public:
   }
 
   virtual Any visitSimpleExprNot(MySQLParser::SimpleExprNotContext *context) override {
-    EvalValue value = visit(context->simpleExpr());
+    EvalValue value = std::any_cast<EvalValue>(visit(context->simpleExpr()));
     if (value.isNullType())
       return EvalValue::fromNull();
     return EvalValue::fromBool(!asBool(value));
@@ -616,6 +618,9 @@ $TestData {
 
   MySQLParserServices *services;
 
+  // Use the app's version also as the latest/current server version for tests.
+  long currentVersion = APP_MAJOR_NUMBER * 10000 + APP_MINOR_NUMBER * 100 + APP_BUILD_NUMBER;
+
   //--------------------------------------------------------------------------------------------------------------------
 
   /**
@@ -785,10 +790,10 @@ $describe("MySQL parser test suite (ANTLR)") {
           if (result.first > 0U) {
             $fail("This query failed to parse (5.7.20):\n" + statement + "\n with error: " + result.second);
           }
-        } else if (versionMatches(statement, 80018)) {
-          auto result = data->parse(statement, 80018, "ANSI_QUOTES");
+        } else if (versionMatches(statement, 80021)) {
+          auto result = data->parse(statement, 80021, "ANSI_QUOTES");
           if (result.first > 0U) {
-            $fail("This query failed to parse (8.0.18):\n" + statement + "\n with error: " + result.second);
+            $fail("This query failed to parse (8.0.21):\n" + statement + "\n with error: " + result.second);
           }
         } else
           $fail("Invalid version number found in query: " + statement);
